@@ -14,7 +14,6 @@
 #include <klocale.h>
 #include <kconfig.h>
 #include <kcolordialog.h>
-#include <kbuttonbox.h>
 #include <kcolorbutton.h>
 #include "gravity.h"
 #include "gravity.moc"
@@ -33,34 +32,46 @@
 #include <kstandarddirs.h>
 #include <math.h>
 #include <kmessagebox.h>
+#include <krandom.h>
 // libkscreensaver interface
-extern "C"
+class KGravitySaverInterface : public KScreenSaverInterface
 {
-	KDE_EXPORT const char *kss_applicationName = "kgravity.kss";
-	KDE_EXPORT const char *kss_description = I18N_NOOP( "Particle Gravity Screen Saver" );
-	KDE_EXPORT const char *kss_version = "2.2.0";
 
-	KDE_EXPORT KScreenSaver *kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "kgravity.kss", 0, ki18n( "Particle Gravity Screen Saver" ), "2.2.0", ki18n( "Particle Gravity Screen Saver" ) );
+    }
+
+
+	virtual KScreenSaver* create( WId id )
 	{
 		return new KGravitySaver( id );
 	}
 
-	KDE_EXPORT QDialog *kss_setup()
+	virtual QDialog* setup()
 	{
 		return new KGravitySetup();
 	}
+};
+
+int main( int argc, char *argv[] )
+{
+    KGravitySaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 //-----------------------------------------------------------------------------
 // dialog to setup screen saver parameters
 //
-KGravitySetup::KGravitySetup( QWidget *parent, const char *name )
-	: SetupUi( parent, name, TRUE )
+KGravitySetup::KGravitySetup( QWidget *parent )
+	 : QDialog(parent)
 {
+	setupUi(this);
 	readSettings();
 
 	preview->setFixedSize( 220, 170 );
-	preview->setBackgroundColor( black );
+	preview->setBackgroundColor( Qt::black );
 #ifdef Q_WS_X11
 	preview->show();    // otherwise saver does not get correct size
 #endif
@@ -82,9 +93,8 @@ KGravitySetup::~KGravitySetup()
 // read settings from config file
 void KGravitySetup::readSettings()
 {
-	KConfig config("kssgravityrc", false, false);
+	KConfigGroup  config = KConfig("kssgravityrc", KConfig::NoGlobals).group("Settings");
 
-	config.setGroup( "Settings" );
 	QString boolval = config.readEntry( "Stars", "false" );
 	if (boolval == "true") {
 		RadioButton1->setDown(true);
@@ -105,8 +115,8 @@ void KGravitySetup::readSettings()
 // Ok pressed - save settings and exit
 void KGravitySetup::slotOkPressed()
 {
-	KConfig config("kssgravityrc", false, false);
-	config.setGroup( "Settings" );
+	KConfig _config("kssgravityrc", KConfig::NoGlobals);
+	KConfigGroup config(&_config, "Settings" );
 
 	if (RadioButton1->isOn() == true)
 	{
@@ -135,18 +145,19 @@ void KGravitySetup::aboutPressed()
 KGravitySaver::KGravitySaver( WId id ) : KScreenSaver( id )
 {
 
-	kdDebug() << "Blank" << endl;
+    kDebug() << "Blank";
 
-	timer = new QTimer( this );
-    	timer->start( 25, TRUE );
-	setBackgroundColor( black );
-        erase();
-	gravity = new Gravity();
-	embed(gravity);
+    timer = new QTimer( this );
+    timer->setSingleShot(true);
+    timer->start( 25);
+    setBackgroundColor( Qt::black );
+    update();
+    gravity = new Gravity();
+    embed(gravity);
 #ifdef Q_WS_X11
-	gravity->show();
+    gravity->show();
 #endif
-	connect( timer, SIGNAL(timeout()), this, SLOT(blank()) );
+    connect( timer, SIGNAL(timeout()), this, SLOT(blank()) );
 }
 
 KGravitySaver::~KGravitySaver()
@@ -166,10 +177,11 @@ void KGravitySaver::blank()
 	// Play gravity
 
 	gravity->updateGL();
-	timer->start( 25, TRUE );
+    timer->setSingleShot(true);
+	timer->start( 25);
 
 }
-Gravity::Gravity( QWidget * parent, const char * name) : QGLWidget (parent,name)
+Gravity::Gravity( QWidget * parent ) : QGLWidget (parent)
 {
 	rainbow=true;
 	slowdown=2.0f;
@@ -179,8 +191,8 @@ Gravity::Gravity( QWidget * parent, const char * name) : QGLWidget (parent,name)
 //	obj = gluNewQuadric();
 
 // This has to be here because you can't update the gravity until 'gravity' is created!
-	KConfig config("kssgravityrc", false, false);
-	config.setGroup( "Settings" );
+	KConfig _config("kssgravityrc", KConfig::NoGlobals);
+	KConfigGroup config(&_config, "Settings" );
 	QString boolval = config.readEntry( "Stars", "false" );
 	if (boolval == "true") {
 		setStars(true);
@@ -207,26 +219,26 @@ Gravity::~Gravity()
 bool Gravity::loadParticle()
 {
     /* Status indicator */
-    bool Status = TRUE;
-	QImage buf;
+    bool Status = true;
+    QImage buf;
 
-    kdDebug() << "Loading: " << locate("data", "kscreensaver/particle.png") << endl;
- if (buf.load( locate("data", "kscreensaver/particle.png") ) )
+    kDebug() << "Loading: " << KStandardDirs::locate("data", "kscreensaver/particle.png");
+ if (buf.load( KStandardDirs::locate("data", "kscreensaver/particle.png") ) )
 
         {
 		tex = convertToGLFormat(buf);  // flipped 32bit RGBA
-		kdDebug() << "Texture loaded: " << tex.numBytes () << endl;
+		kDebug() << "Texture loaded: " << tex.numBytes ();
 	}
 	else
 	{
 		QImage dummy( 32, 32, 32 );
-  		dummy.fill( Qt::white.rgb() );
+  		dummy.fill( Qt::white );
         	buf = dummy;
 		tex = convertToGLFormat( buf );
 	}
 
             /* Set the status to true */
-            //Status = TRUE;
+            //Status = true;
 	glGenTextures(1, &texture[0]);   /* create three textures */
 	glBindTexture(GL_TEXTURE_2D, texture[0]);
 	/* use linear filtering */
@@ -240,11 +252,11 @@ bool Gravity::loadParticle()
 
     return Status;
 }
-/** setup the GL enviroment */
+/** setup the GL environment */
 void Gravity::initializeGL ()
 {
 
-	kdDebug() << "InitGL" << endl;
+	kDebug() << "InitGL";
 
 	if (loadParticle())						// Jump To Texture Loading Routine
 	{
@@ -287,7 +299,7 @@ void Gravity::initializeGL ()
 /** resize the gl view */
 void Gravity::resizeGL ( int width, int height )
 {
-	kdDebug() << "ResizeGL " << width << "," <<height<< endl;
+	kDebug() << "ResizeGL " << width << "," <<height;
 	if (height==0)							// Prevent A Divide By Zero By
 	{
 		height=1;						// Making Height Equal One
@@ -307,7 +319,7 @@ void Gravity::resizeGL ( int width, int height )
 /** paint the GL view */
 void Gravity::paintGL ()
 {
-	//kdDebug() << "PaintGL" << endl;
+	//kDebug() << "PaintGL";
 	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);		// Clear Screen And Depth Buffer
 	glLoadIdentity();
 						// Reset The ModelView Matrix
@@ -398,18 +410,18 @@ void Gravity::buildParticle(int loop)
 	{0.5f,0.5f,1.0f},{0.75f,0.5f,1.0f},{1.0f,0.5f,1.0f},{1.0f,0.5f,0.75f}};
 	col = ( ++col ) % 12;
 	particle[loop].active=true;
-	particle[loop].index=KApplication::random()%100;
+	particle[loop].index=KRandom::random()%100;
 	particle[loop].indexo=particle[loop].index;
-	particle[loop].fade=float(KApplication::random()%100)/1000.0f+0.003f;	// Random Fade Value
+	particle[loop].fade=float(KRandom::random()%100)/1000.0f+0.003f;	// Random Fade Value
 	particle[loop].r=colors[col][0];			// Select Red From Color Table
 	particle[loop].g=colors[col][1];			// Select Green From Color Table
 	particle[loop].b=colors[col][2];			// Select Blue From Color Table
 	particle[loop].size=size;
-	particle[loop].x = float(KApplication::random()%100-50)*4.0;
-	particle[loop].y = float(KApplication::random()%20-10)*4.0;
-	particle[loop].z = float(KApplication::random()%100-50)*4.0;
+	particle[loop].x = float(KRandom::random()%100-50)*4.0;
+	particle[loop].y = float(KRandom::random()%20-10)*4.0;
+	particle[loop].z = float(KRandom::random()%100-50)*4.0;
 	particle[loop].xo = particle[loop].x;
-	if ((1+(KApplication::random() % 10) > 5))
+	if ((1+(KRandom::random() % 10) > 5))
 		particle[loop].yo = particle[loop].y;
 	else
 		particle[loop].yo = 0.0;
