@@ -8,12 +8,13 @@
 // layout management added 1998/04/19 by Mario Weilguni <mweilguni@kde.org>
 // 2001/03/04 Converted to libkscreensaver by Martin R. Jones
 
-#include <config.h>
 #include <stdlib.h>
 #include <time.h>
 #include <qcolor.h>
 #include <qlabel.h>
 #include <qslider.h>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 #include <kconfig.h>
 #include <kapplication.h>
 #include <kmessagebox.h>
@@ -31,21 +32,31 @@
 #define MAXLENGTH	256
 
 // libkscreensaver interface
-extern "C"
+class kLinesSaverInterface : public KScreenSaverInterface
 {
-    const char *kss_applicationName = "klines.kss";
-    const char *kss_description = I18N_NOOP( "KLines" );
-    const char *kss_version = "2.2.0";
 
-    KScreenSaver *kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "klines.kss", 0, ki18n( "KLines" ), "2.2.0", ki18n( "KLines" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId id )
     {
         return new kLinesSaver( id );
     }
 
-    QDialog *kss_setup()
+    virtual QDialog* setup()
     {
         return new kLinesSetup();
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    kLinesSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 // Methods of the Lines-class
@@ -112,14 +123,20 @@ void Lines::turn(const int& w, const int& h){
 //-----------------------------------------------------------------------------
 // dialog to setup screen saver parameters
 //
-kLinesSetup::kLinesSetup(QWidget *parent, const char *name)
-	: KDialogBase(parent, name, true, i18n( "Setup Lines Screen Saver" ),
-	  Ok|Cancel|Help, Ok, true ), saver( 0 ), length( 10 ), speed( 50 )
+kLinesSetup::kLinesSetup(QWidget *parent)
+	: KDialog(parent)
+	  , saver( 0 ), length( 10 ), speed( 50 )
 {
+	setCaption(i18n( "Setup Lines Screen Saver" ));
+	setModal(true);
+	setButtons(Ok|Cancel|Help);
+	setDefaultButton(Ok);
+
 	readSettings();
 
 	setButtonText( Help, i18n( "A&bout" ) );
-	QWidget *main = makeMainWidget();
+	QWidget *main = new QWidget(this);
+	setMainWidget(main);
 
 	QHBoxLayout *tl = new QHBoxLayout(main, 0, spacingHint());
 	QVBoxLayout *tl1 = new QVBoxLayout;
@@ -128,10 +145,10 @@ kLinesSetup::kLinesSetup(QWidget *parent, const char *name)
 	QLabel *label=new QLabel(i18n("Length:"), main);
 	tl1->addWidget(label);
 
-	QSlider *sb= new QSlider(1, MAXLENGTH+1, 16, length, QSlider::Horizontal,
+	QSlider *sb= new QSlider(1, MAXLENGTH+1, 16, length, Qt::Horizontal,
 		main);
 	sb->setMinimumSize(120, 20);
-	sb->setTickmarks(QSlider::Below);
+	sb->setTickPosition(QSlider::TicksBelow);
 	sb->setTickInterval(32);
 	connect(sb, SIGNAL(valueChanged(int)), SLOT(slotLength(int)));
 	tl1->addWidget(sb);
@@ -139,9 +156,9 @@ kLinesSetup::kLinesSetup(QWidget *parent, const char *name)
 	label=new QLabel(i18n("Speed:"), main);
 	tl1->addWidget(label);
 
-	sb = new QSlider(0, 100, 10, speed, QSlider::Horizontal, main);
+	sb = new QSlider(0, 100, 10, speed, Qt::Horizontal, main);
 	sb->setMinimumSize(120, 20);
-	sb->setTickmarks(QSlider::Below);
+	sb->setTickPosition(QSlider::TicksBelow);
 	sb->setTickInterval(10);
 	connect( sb, SIGNAL( valueChanged( int ) ), SLOT( slotSpeed( int ) ) );
 	tl1->addWidget(sb);
@@ -173,10 +190,12 @@ kLinesSetup::kLinesSetup(QWidget *parent, const char *name)
 
 	preview = new QWidget( main );
 	preview->setFixedSize( 220, 170 );
-	preview->setBackgroundColor( black );
+	preview->setBackgroundColor( Qt::black );
 	preview->show();    // otherwise saver does not get correct size
 	saver=new kLinesSaver(preview->winId());
 	tl->addWidget(preview);
+	connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
+	connect(this,SIGNAL(helpClicked()),this,SLOT(slotHelp()));
 }
 
 kLinesSetup::~kLinesSetup()
@@ -186,28 +205,27 @@ kLinesSetup::~kLinesSetup()
 
 // read settings from config file
 void kLinesSetup::readSettings(){
-    KConfig *config = KGlobal::config();
-    config->setGroup( "Settings" );
+    KConfigGroup config(KGlobal::config(), "Settings");
 
     QString str;
 
-    length = config->readNumEntry("Length", length);
+    length = config.readEntry("Length", length);
     if(length>MAXLENGTH) length=MAXLENGTH;
     else if(length<1) length=1;
 
-    speed = config->readNumEntry("Speed", speed);
+    speed = config.readEntry("Speed", speed);
     if(speed>100) speed=100;
     else if(speed<50) speed=50;
 
-    str=config->readEntry("StartColor");
+    str=config.readEntry("StartColor");
     if(!str.isNull()) colstart.setNamedColor(str);
-    else colstart=white;
-    str=config->readEntry("MidColor");
+    else colstart=Qt::white;
+    str=config.readEntry("MidColor");
     if(!str.isNull()) colmid.setNamedColor(str);
-    else colmid=blue;
-    str=config->readEntry("EndColor");
+    else colmid=Qt::blue;
+    str=config.readEntry("EndColor");
     if(!str.isNull()) colend.setNamedColor(str);
-    else colend=black;
+    else colend=Qt::black;
 }
 
 void kLinesSetup::slotLength(int len){
@@ -244,31 +262,30 @@ void kLinesSetup::slotHelp(){
 
 // Ok pressed - save settings and exit
 void kLinesSetup::slotOk(){
-    KConfig *config = KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config(KGlobal::config(), "Settings");
 
     QString slength;
     slength.setNum(length);
-    config->writeEntry("Length", slength);
+    config.writeEntry("Length", slength);
 
     QString sspeed;
     sspeed.setNum( speed );
-    config->writeEntry( "Speed", sspeed );
+    config.writeEntry( "Speed", sspeed );
 
     QString colName0, colName1, colName2;
     colName0.sprintf("#%02x%02x%02x", colstart.red(),
 		     colstart.green(), colstart.blue() );
-    config->writeEntry( "StartColor", colName0 );
+    config.writeEntry( "StartColor", colName0 );
 
     colName1.sprintf("#%02x%02x%02x", colmid.red(),
 		     colmid.green(), colmid.blue() );
-    config->writeEntry( "MidColor", colName1 );
+    config.writeEntry( "MidColor", colName1 );
 
     colName2.sprintf("#%02x%02x%02x", colend.red(),
 		     colend.green(), colend.blue() );
-    config->writeEntry( "EndColor", colName2 );
+    config.writeEntry( "EndColor", colName2 );
 
-    config->sync();
+    config.sync();
     accept();
 }
 
@@ -278,7 +295,6 @@ void kLinesSetup::slotOk(){
 kLinesSaver::kLinesSaver( WId id ) : KScreenSaver( id ){
 	readSettings();
 	lines=new Lines(numLines);
-	colorContext=QColor::enterAllocContext();
 	blank();
 	initialiseColor();
 	initialiseLines();
@@ -288,8 +304,6 @@ kLinesSaver::kLinesSaver( WId id ) : KScreenSaver( id ){
 
 kLinesSaver::~kLinesSaver(){
 	timer.stop();
-	QColor::leaveAllocContext();
-	QColor::destroyAllocContext(colorContext);
 	delete lines;
 }
 
@@ -319,28 +333,29 @@ void kLinesSaver::setColor(const QColor& cs, const QColor& cm, const QColor& ce)
 
 // read configuration settings from config file
 void kLinesSaver::readSettings(){
-    KConfig *config=KGlobal::config();
-    config->setGroup("Settings");
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    numLines=config->readNumEntry("Length", 10);
-    speed = 100- config->readNumEntry("Speed", 50);
+    numLines=config.readEntry("Length", 10);
+    speed = 100- config.readEntry("Speed", 50);
     if(numLines>MAXLENGTH) numLines=MAXLENGTH;
     else if(numLines<1) numLines = 1;
 
-    colstart=config->readColorEntry("StartColor", &white);
-    colmid=config->readColorEntry("MidColor", &blue);
-    colend=config->readColorEntry("EndColor", &black);
+    colstart=config.readEntry("StartColor", QColor(Qt::white));
+    colmid=config.readEntry("MidColor", QColor(Qt::blue));
+    colend=config.readEntry("EndColor", QColor(Qt::black));
 }
 
 // draw next lines and erase tail
 void kLinesSaver::slotTimeout(){
+   update();
+/*
 	uint i;
 	int x1,y1,x2,y2;
 	int col=0;
 
 	lines->reset();
     QPainter p( this );
-    p.setPen( black );
+    p.setPen( Qt::black );
 
 	for(i=0; i<numLines; i++){
 		lines->getKoord(x1,y1,x2,y2);
@@ -350,11 +365,34 @@ void kLinesSaver::slotTimeout(){
 		if(col>63) col=0;
 	}
 	lines->turn(width(), height());
+*/
+}
+
+void kLinesSaver::paintEvent(QPaintEvent *)
+{
+        uint i;
+        int x1,y1,x2,y2;
+        int col=0;
+
+        lines->reset();
+
+     QPainter p( this );
+    p.setPen( Qt::black );
+
+        for(i=0; i<numLines; i++){
+                lines->getKoord(x1,y1,x2,y2);
+        p.drawLine( x1, y1, x2, y2 );
+                p.setPen( colors[col] );
+                col=(int)(i*colscale);
+                if(col>63) col=0;
+        }
+        lines->turn(width(), height());
+
 }
 
 void kLinesSaver::blank(){
-	setBackgroundColor( black );
-	erase();
+	setBackgroundColor( Qt::black );
+	update();
 }
 
 // initialise the lines
