@@ -5,13 +5,12 @@
 // based on kpolygon 0.3 by Martin R. Jones 1996
 //
 
-#ifndef __LINES_H__
-#define __LINES_H__
+#ifndef LINES_H
+#define LINES_H
 
 #include <qtimer.h>
-#include <qptrlist.h>
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <krandomsequence.h>
 #include <kscreensaver.h>
 
@@ -54,22 +53,24 @@ class kLinesSaver:public KScreenSaver{
 
 	protected slots:
 	void slotTimeout();
+	protected:
+        void paintEvent(QPaintEvent *event);
 
 	protected:
 	KRandomSequence rnd;
 	QTimer timer;
 	unsigned numLines;
-	int colorContext, speed;
+	int speed;
 	QColor colors[64];
     QColor colstart, colmid, colend;
 	double colscale;
 	Lines* lines;
 };
 
-class kLinesSetup : public KDialogBase{
+class kLinesSetup : public KDialog{
 	Q_OBJECT
 	public:
-	kLinesSetup(QWidget *parent=NULL, const char *name=NULL);
+	kLinesSetup(QWidget *parent=NULL);
     ~kLinesSetup();
 
 	protected:
