@@ -5,13 +5,15 @@
 // Copyright (c)  Martin R. Jones 1996
 //
 
-#ifndef __POLYGON_H__
-#define __POLYGON_H__
+#ifndef POLYGON_H
+#define POLYGON_H
 
 #include <qtimer.h>
-#include <qptrlist.h>
+#include <Q3PointArray>
+#include <Q3MemArray>
+#include <Q3PtrList>
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 #include <kscreensaver.h>
 #include <krandomsequence.h>
 
@@ -33,27 +35,26 @@ private:
 	void initialiseColor();
 	void nextColor();
 
-protected slots:
-	void slotTimeout();
+protected:
+	void paintEvent(QPaintEvent *event);
 
 protected:
 	QTimer		timer;
 	unsigned	numLines;
 	int			numVertices;
-	int			colorContext;
 	int			speed;
 	QColor		colors[64];
     int         currentColor;
-	QPtrList<QPointArray> polygons;
-	QMemArray<QPoint> directions;
+	Q3PtrList<Q3PointArray> polygons;
+	Q3MemArray<QPoint> directions;
 	KRandomSequence rnd;
 };
 
-class kPolygonSetup : public KDialogBase
+class kPolygonSetup : public KDialog
 {
 	Q_OBJECT
 public:
-	kPolygonSetup( QWidget *parent = 0, const char *name = 0 );
+	kPolygonSetup( QWidget *parent = 0 );
     ~kPolygonSetup();
 
 protected:
