@@ -5,7 +5,6 @@
 // Copyright (c)  Rene Beutler 1998
 //
 
-#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -15,10 +14,11 @@
 #include <qpainter.h>
 #include <qpixmap.h>
 #include <qlabel.h>
-#include <qlistbox.h>
+#include <q3listbox.h>
 #include <qcheckbox.h>
 #include <qslider.h>
 #include <qlayout.h>
+#include <QPaintEvent>
 
 #include <kapplication.h>
 #include <kglobal.h>
@@ -52,21 +52,31 @@
 
 
 // libkscreensaver interface
-extern "C"
+class KScienceSaverInterface : public KScreenSaverInterface
 {
-    KDE_EXPORT const char *kss_applicationName = "kscience.kss";
-    KDE_EXPORT const char *kss_description = I18N_NOOP( "Science Screen Saver" );
-    KDE_EXPORT const char *kss_version = "2.2.0";
 
-    KDE_EXPORT KScreenSaver *kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "kscience.kss", 0, ki18n( "Science Screen Saver" ), "2.2.0", ki18n( "Science Screen Saver" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId id )
     {
         return new KScienceSaver( id );
     }
 
-    KDE_EXPORT QDialog *kss_setup()
+    virtual QDialog* setup()
     {
         return new KScienceSetup();
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    KScienceSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 static struct {
@@ -131,35 +141,35 @@ KScienceSaver::KScienceSaver( WId id, bool s, bool gP )
     : KScreenSaver( id )
 {
     d = new KScienceData;
-    d->gc = XCreateGC(qt_xdisplay(), id, 0, 0);
-	d->xRootWin = 0;
+    d->gc = XCreateGC(QX11Info::display(), id, 0, 0);
+    d->xRootWin = 0;
     d->buffer = 0;
 
-	moveOn = true;
-	grabPixmap = gP;
-	setup = s;
+    moveOn = true;
+    grabPixmap = gP;
+    setup = s;
 
-	vx = vy = 0.0;
-	readSettings();
+    vx = vy = 0.0;
+    readSettings();
 
-	if( !grabPixmap )
-	{
-		grabRootWindow();
-		initialize();
-		do_refresh( QRect ( 0, 0, width(), height() ) );
-	}
+    if( !grabPixmap )
+    {
+        grabRootWindow();
+        initialize();
+        do_refresh( QRect ( 0, 0, width(), height() ) );
+    }
 
-	connect( &timer, SIGNAL( timeout() ), SLOT( slotTimeout() ) );
-	timer.start( SCI_MAX_SPEED - speed[mode] );
+    connect( &timer, SIGNAL( timeout() ), SLOT( slotTimeout() ) );
+    timer.start( SCI_MAX_SPEED - speed[mode] );
 }
 
 KScienceSaver::~KScienceSaver()
 {
-	timer.stop();
-	releaseLens();
-	if ( d->xRootWin )
-		XDestroyImage( d->xRootWin );
-    XFreeGC(qt_xdisplay(), d->gc );
+    timer.stop();
+    releaseLens();
+    if ( d->xRootWin )
+        XDestroyImage( d->xRootWin );
+    XFreeGC(QX11Info::display(), d->gc );
     delete d;
 }
 
@@ -410,7 +420,7 @@ void KScienceSaver::initLens()
 	side  = origin << 1;
 
 	d->buffer = XSubImage( d->xRootWin, 0, 0, side, side );
-        myAssert( d->buffer != 0, "can't allocate pixmap" );
+        myAssert( d->buffer != 0, "cannot allocate pixmap" );
 
 	d->offset = (T32bit **) malloc( sizeof(T32bit *) * side );
 	myAssert( d->offset != 0, "too few memory" );
@@ -560,24 +570,23 @@ void KScienceSaver::setHideBG( bool b )
 
 void KScienceSaver::readSettings()
 {
-    KConfig *config = KGlobal::config();
+    KConfigGroup group = KGlobal::config()->group("Settings");
         QString sMode;
 
-	config->setGroup( "Settings" );
-	mode = config->readNumEntry( "ModeNr", SCI_DEFAULT_MODE );
+	mode = group.readEntry( "ModeNr", SCI_DEFAULT_MODE );
 
 	for(int i=0; i < MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		config->setGroup( "Mode" + sMode );
-		moveX[i]     = config->readNumEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
-		moveY[i]     = config->readNumEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
-		size[i]      = config->readNumEntry(  "Size",      SCI_DEFAULT_SIZE);
-		speed[i]     = config->readNumEntry(  "Speed",     SCI_DEFAULT_SPEED);
-		intensity[i] = config->readNumEntry(  "Intensity", SCI_DEFAULT_INTENSITY);
-		inverse[i]   = config->readBoolEntry( "Inverse",   SCI_DEFAULT_INVERSE);
-		gravity[i]   = config->readBoolEntry( "Gravity",   SCI_DEFAULT_GRAVITY);
-		hideBG[i]    = config->readBoolEntry( "HideBG",    SCI_DEFAULT_HIDE);
+		group = KGlobal::config()->group( "Mode" + sMode );
+		moveX[i]     = group.readEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
+		moveY[i]     = group.readEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
+		size[i]      = group.readEntry(  "Size",      SCI_DEFAULT_SIZE);
+		speed[i]     = group.readEntry(  "Speed",     SCI_DEFAULT_SPEED);
+		intensity[i] = group.readEntry(  "Intensity", SCI_DEFAULT_INTENSITY);
+		inverse[i]   = group.readEntry( "Inverse",   SCI_DEFAULT_INVERSE);
+		gravity[i]   = group.readEntry( "Gravity",   SCI_DEFAULT_GRAVITY);
+		hideBG[i]    = group.readEntry( "HideBG",    SCI_DEFAULT_HIDE);
 	}
 
 	vx = copysign( moveX[mode], vx );
@@ -592,14 +601,14 @@ void KScienceSaver::do_refresh( const QRect & rect )
 
 	if( hideBG[mode] )
 	{
-		XSetWindowBackground( qt_xdisplay(), winId(), black.pixel() );
-		XClearArea( qt_xdisplay(), winId(), rect.left(), rect.top(),
+		XSetWindowBackground( QX11Info::display(), winId(), QColor(Qt::black).pixel() );
+		XClearArea( QX11Info::display(), winId(), rect.left(), rect.top(),
                             rect.width(), rect.height(), false );
 	}
 	else
 	{
 		myAssert( d->xRootWin != 0, "root window not grabbed" );
-		XPutImage( qt_xdisplay(), winId(), d->gc, d->xRootWin,
+		XPutImage( QX11Info::display(), winId(), d->gc, d->xRootWin,
 		           rect.left(), rect.top(),
                            rect.left(), rect.top(),
                            rect.width(), rect.height() );
@@ -700,15 +709,15 @@ void KScienceSaver::slotTimeout()
 	if( hideBG[mode] )
 		blackPixel( xcoord, ycoord );
 	(this->*applyLens)(xs, ys, xd, yd, w, h);
-	XPutImage( qt_xdisplay(), winId(), d->gc, d->buffer, 0, 0, xd, yd, w, h );
+	XPutImage( QX11Info::display(), winId(), d->gc, d->buffer, 0, 0, xd, yd, w, h );
 	if( hideBG[mode] )
 		blackPixelUndo( xcoord, ycoord );
 }
 
 void KScienceSaver::grabRootWindow()
 {
-	Display *dsp = qt_xdisplay();
-	Window rootwin = RootWindow( dsp, qt_xscreen() );
+	Display *dsp = QX11Info::display();
+	Window rootwin = RootWindow( dsp, QX11Info::appScreen() );
 
 	// grab contents of root window
 	if( d->xRootWin )
@@ -724,12 +733,12 @@ void KScienceSaver::grabRootWindow()
 
 void KScienceSaver::grabPreviewWidget()
 {
-	myAssert( QWidget::find(winId())->isActiveWindow(), "can't grab preview widget: dialog not active()" );
+	myAssert( QWidget::find(winId())->isActiveWindow(), "cannot grab preview widget: dialog not active()" );
 
 	if( d->xRootWin )
 		XDestroyImage( d->xRootWin );
 
-	Display *dsp = qt_xdisplay();
+	Display *dsp = QX11Info::display();
 	d->xRootWin = XGetImage( dsp, winId(), 0, 0, width(), height(), AllPlanes, ZPixmap);
 	myAssert( d->xRootWin, "unable to grab preview window\n" );
 
@@ -739,7 +748,7 @@ void KScienceSaver::grabPreviewWidget()
 
 void KScienceSaver::blackPixel( int x, int y )
 {
-	unsigned char black = (char) BlackPixel( qt_xdisplay(), qt_xscreen() );
+	unsigned char black = (char) BlackPixel( QX11Info::display(), QX11Info::appScreen() );
 	unsigned int adr = x*bpp + y*imgnext;
 
 	for(int i=0; i<bpp; i++) {
@@ -846,14 +855,20 @@ void KScienceSaver::applyLens32bpp(int xs, int ys, int xd, int yd, int w, int h)
 
 //-----------------------------------------------------------------------------
 
-KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
-	: KDialogBase( parent, name, true, i18n( "Setup Science Screen Saver" ),
-	  Ok|Cancel|Help, Ok, true ), saver( 0 )
+KScienceSetup::KScienceSetup(  QWidget *parent )
+	: KDialog( parent)
+	  , saver( 0 )
 {
+	setCaption(i18n( "Setup Science Screen Saver" ));
+	setModal(true);
+	setButtons(Ok|Cancel|Help);
+	setDefaultButton(Ok);
+	showButtonSeparator(true);
 	readSettings();
 	initModeInfo();
 
-	QWidget *main = makeMainWidget();
+	QWidget *main = new QWidget(this);
+	setMainWidget(main);
 
 	QHBoxLayout *lt  = new QHBoxLayout( main, 0, spacingHint());
 	QVBoxLayout *ltm = new QVBoxLayout;
@@ -865,7 +880,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	QLabel *label = new QLabel( i18n("Mode:"), main );
 	ltm->addWidget( label );
 
-	QListBox *c = new QListBox( main );
+	Q3ListBox *c = new Q3ListBox( main );
 	for(int i = 0; i<MAX_MODES; i++)
 		c->insertItem( modeInfo[i].name );
 	c->setCurrentItem( mode );
@@ -897,10 +912,10 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	label = new QLabel( i18n("Size:"), main );
 	ltc->addWidget( label );
 
-	slideSize = new QSlider(9, 50, 5, size[mode], QSlider::Horizontal,
+	slideSize = new QSlider(9, 50, 5, size[mode], Qt::Horizontal,
                                 main );
 	slideSize->setMinimumSize( 90, 20 );
-    slideSize->setTickmarks(QSlider::Below);
+    slideSize->setTickPosition(QSlider::TicksBelow);
     slideSize->setTickInterval(5);
 	connect( slideSize, SIGNAL( sliderMoved( int ) ),
 		SLOT( slotSize( int ) ) );
@@ -916,9 +931,9 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	ltc->addWidget( label );
 
 	slideIntensity = new QSlider(0, 10, 1, intensity[mode],
-                                     QSlider::Horizontal, main );
+                                     Qt::Horizontal, main );
 	slideIntensity->setMinimumSize( 90, 20 );
-    slideIntensity->setTickmarks(QSlider::Below);
+    slideIntensity->setTickPosition(QSlider::TicksBelow);
     slideIntensity->setTickInterval(1);
 	connect( slideIntensity, SIGNAL( sliderMoved( int ) ),
 		SLOT( slotIntensity( int )) );
@@ -933,9 +948,9 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	ltc->addWidget( label );
 
 	slideSpeed = new QSlider(0, SCI_MAX_SPEED, 10, speed[mode],
-                             QSlider::Horizontal, main );
+                             Qt::Horizontal, main );
 	slideSpeed->setMinimumSize( 90, 20 );
-    slideSpeed->setTickmarks(QSlider::Below);
+    slideSpeed->setTickPosition(QSlider::TicksBelow);
     slideSpeed->setTickInterval(10);
 	connect( slideSpeed, SIGNAL( sliderMoved( int ) ),
 		SLOT( slotSpeed( int ) ) );
@@ -949,18 +964,18 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	ltc->addLayout( ltcm );
 
 	slideMoveX = new QSlider(0, SCI_MAX_MOVE, 5, moveX[mode],
-                                 QSlider::Horizontal, main );
+                                 Qt::Horizontal, main );
 	slideMoveX->setMinimumSize( 40, 20 );
-    slideMoveX->setTickmarks(QSlider::Below);
+    slideMoveX->setTickPosition(QSlider::TicksBelow);
     slideMoveX->setTickInterval(5);
 	connect( slideMoveX, SIGNAL( sliderMoved( int ) ),
 		SLOT( slotMoveX( int ) ) );
 	ltcm->addWidget( slideMoveX );
 
 	slideMoveY = new QSlider(0, SCI_MAX_MOVE, 5, moveY[mode],
-                                QSlider::Horizontal, main );
+                                Qt::Horizontal, main );
 	slideMoveY->setMinimumSize( 40, 20 );
-    slideMoveY->setTickmarks(QSlider::Below);
+    slideMoveY->setTickPosition(QSlider::TicksBelow);
     slideMoveY->setTickInterval(5);
 	connect( slideMoveY, SIGNAL( sliderMoved( int ) ),
 		SLOT( slotMoveY( int ) ) );
@@ -971,9 +986,9 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 	// preview
 	preview = new KPreviewWidget( main );
 	preview->setFixedSize( 220, 170 );
-	QPixmap p( locate("data", "kscreensaver/pics/kscience.png") );
+	QPixmap p( KStandardDirs::locate("data", "kscreensaver/pics/kscience.png") );
 	if( p.isNull() )
-		preview->setBackgroundColor( black );
+		preview->setBackgroundColor( Qt::black );
 	else
 		preview->setBackgroundPixmap( p );
 	preview->show();	// otherwise saver does not get correct size
@@ -984,6 +999,8 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name )
 
 	saver = new KScienceSaver( preview->winId(), true, !p.isNull() );
 	preview->notifySaver( saver );
+	connect(this,SIGNAL(okClicked()),SLOT(slotOk()));
+	connect(this,SIGNAL(helpClicked()),SLOT(slotHelp()));
 }
 
 KScienceSetup::~KScienceSetup()
@@ -1008,24 +1025,23 @@ void KScienceSetup::updateSettings()
 // read settings from config file
 void KScienceSetup::readSettings()
 {
-    KConfig *config = KGlobal::config();
+    KConfigGroup group = KGlobal::config()->group("Settings");
         QString sMode;
 
-	config->setGroup( "Settings" );
-	mode = config->readNumEntry( "ModeNr", SCI_DEFAULT_MODE );
+	mode = group.readEntry( "ModeNr", SCI_DEFAULT_MODE );
 
 	for(int i=0; i < MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		config->setGroup( "Mode" + sMode );
-		moveX[i]     = config->readNumEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
-		moveY[i]     = config->readNumEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
-		size[i]      = config->readNumEntry(  "Size",      SCI_DEFAULT_SIZE);
-		speed[i]     = config->readNumEntry(  "Speed",     SCI_DEFAULT_SPEED);
-		intensity[i] = config->readNumEntry(  "Intensity", SCI_DEFAULT_INTENSITY);
-		inverse[i]   = config->readBoolEntry( "Inverse",   SCI_DEFAULT_INVERSE);
-		gravity[i]   = config->readBoolEntry( "Gravity",   SCI_DEFAULT_GRAVITY);
-		hideBG[i]    = config->readBoolEntry( "HideBG",    SCI_DEFAULT_HIDE);
+		group = KGlobal::config()->group( "Mode" + sMode );
+		moveX[i]     = group.readEntry(  "MoveX",     SCI_DEFAULT_MOVEX);
+		moveY[i]     = group.readEntry(  "MoveY",     SCI_DEFAULT_MOVEY);
+		size[i]      = group.readEntry(  "Size",      SCI_DEFAULT_SIZE);
+		speed[i]     = group.readEntry(  "Speed",     SCI_DEFAULT_SPEED);
+		intensity[i] = group.readEntry(  "Intensity", SCI_DEFAULT_INTENSITY);
+		inverse[i]   = group.readEntry( "Inverse",   SCI_DEFAULT_INVERSE);
+		gravity[i]   = group.readEntry( "Gravity",   SCI_DEFAULT_GRAVITY);
+		hideBG[i]    = group.readEntry( "HideBG",    SCI_DEFAULT_HIDE);
 	}
 }
 
@@ -1118,27 +1134,26 @@ void KScienceSetup::slotSliderReleased()
 // Ok pressed - save settings and exit
 void KScienceSetup::slotOk()
 {
-    KConfig *config = KGlobal::config();
+    KConfigGroup group = KGlobal::config()->group("Settings");
 	QString sSize, sSpeed, sIntensity, sMode;
 
-	config->setGroup( "Settings" );
-	config->writeEntry( "ModeNr", mode );
+	group.writeEntry( "ModeNr", mode );
 
 	for(int i=0; i<MAX_MODES; i++)
 	{
 		sMode.setNum( i );
-		config->setGroup( "Mode" + sMode );
-		config->writeEntry( "MoveX",     moveX[i]     );
-		config->writeEntry( "MoveY",     moveY[i]     );
-		config->writeEntry( "Size",      size[i]      );
-		config->writeEntry( "Speed",     speed[i]     );
-		config->writeEntry( "Intensity", intensity[i] );
-		config->writeEntry( "Inverse",   inverse[i]   );
-		config->writeEntry( "Gravity",   gravity[i]   );
-		config->writeEntry( "HideBG",    hideBG[i]    );
+		group = KGlobal::config()->group("Mode" + sMode );
+		group.writeEntry( "MoveX",     moveX[i]     );
+		group.writeEntry( "MoveY",     moveY[i]     );
+		group.writeEntry( "Size",      size[i]      );
+		group.writeEntry( "Speed",     speed[i]     );
+		group.writeEntry( "Intensity", intensity[i] );
+		group.writeEntry( "Inverse",   inverse[i]   );
+		group.writeEntry( "Gravity",   gravity[i]   );
+		group.writeEntry( "HideBG",    hideBG[i]    );
 	}
 
-	config->sync();
+	group.sync();
 
 	accept();
 }
