@@ -5,7 +5,7 @@
  *	Copyright (c) 2000-2001, 2002
  *		Chris Lee       <lee@azsites.com>
  *		Lennart Kudling <kudling@kde.org>
- *      	Fredrik Hglund <fredrik@kde.org>
+ *      	Fredrik Höglund <fredrik@kde.org>
  *
  *	Copyright (c) 2003
  *		Luciano Montanaro <mikelima@cirulla.net>
@@ -18,12 +18,22 @@
 #ifndef __CDECLIENT_H
 #define __CDECLIENT_H
 
-#include <qbutton.h>
+#include <q3button.h>
 #include <qbitmap.h>
+//Added by qt3to4:
+#include <QPaintEvent>
+#include <QEvent>
+#include <QBoxLayout>
+#include <QLabel>
+#include <Q3ValueList>
+#include <QShowEvent>
+#include <QVBoxLayout>
+#include <QResizeEvent>
+#include <QMouseEvent>
 #include <kpixmap.h>
 #include <kdecoration.h>
 #include <kdecorationfactory.h>
-
+#include <kcommondecoration.h>
 class QLabel;
 class QBoxLayout;
 class QVBoxLayout;
@@ -35,13 +45,13 @@ class CdeClient;
 
 enum Buttons { BtnMenu=0, BtnHelp, BtnIconify, BtnMax, BtnClose, BtnCount };
 
-class CdeButton : public QButton
+class CdeButton : public Q3Button
 {
 public:
     CdeButton( CdeClient* parent=0, const char* name=0, int btnType=0,
-               const QString& tip=NULL, int realize_btns = LeftButton );
+               const QString& tip=NULL, int realize_btns = Qt::LeftButton );
     void reset();
-    ButtonState lastButton() { return last_button; }
+    Qt::ButtonState lastButton() { return last_button; }
 
 protected:
     void mousePressEvent(QMouseEvent *e);
@@ -71,7 +81,6 @@ protected:
     void showEvent(QShowEvent *);
     void addClientButtons( const QString& );
     void mouseDoubleClickEvent( QMouseEvent* );
-    void wheelEvent( QWheelEvent * );
     void captionChange();
     void desktopChange();
     void activeChange();
@@ -108,7 +117,7 @@ public:
     virtual bool supports( Ability ability );
     virtual bool reset(unsigned long changed);
 
-    QValueList< CdeClientFactory::BorderSize > borderSizes() const;
+    Q3ValueList< CdeClientFactory::BorderSize > borderSizes() const;
 
 };
 
